@@ -21,7 +21,7 @@
 import logging
 from configparser import ConfigParser
 from datetime import datetime
-from os import access, chmod, listdir, makedirs, walk, X_OK
+from os import access, chmod, environ, listdir, makedirs, walk, X_OK
 from os.path import abspath, exists, isdir, join
 from shutil import copy
 
@@ -40,7 +40,14 @@ from dhpython.pydist import guess_dependency, parse_pydep
 
 
 log = logging.getLogger('pypi2deb')
-SPHINX_DIR = {'docs', 'doc', 'doc/build'}
+# The location of sphinx-based documentation can be configured via the
+# environment variable PYPI2DEB_SPHINX_DIRS (colon-separated directories).
+# Disable sphinx support by assigning an empty string to this environment
+# variable.
+try:
+    SPHINX_DIR = set(environ['PYPI2DEB_SPHINX_DIRS'].split(":"))
+except KeyError:
+    SPHINX_DIR = {'docs', 'doc', 'doc/build'}
 INTERPRETER_MAP = {value: key for key, value in PKG_PREFIX_MAP.items()}
 VERSIONED_I_MAP = {'python': 'python2'}
 DESC_STOP_KEYWORDS = {'changelog', 'changes', 'license', 'requirements',
@@ -187,7 +194,7 @@ def _dump_ctx(ctx):
         with open(fpath, 'w') as fp:
             dump(serializable_ctx, fp, indent=' ')
     except Exception:
-        log.debug('canont dump ctx', exc_info=True)
+        log.debug('cannot dump ctx', exc_info=True)
 
 
 def docs(dpath, ctx, env):
@@ -292,7 +299,7 @@ def control(dpath, ctx, env):
             for impl in ctx['interpreters']:
                 impl = INTERPRETER_MAP.get(impl, impl)
                 try:
-                    for i in parse_pydep(impl, fpath):
+                    for i in parse_pydep(impl, fpath)['depends']:
                         ctx['build_depends'].add(i)
                 except Exception as err:
                     log.warn('cannot parse build dependency: %s', err)
